@@ -11,7 +11,7 @@ from poultry.tweet import Coordinates, Tweet
 
 class Config(object):
 
-    default_config_file = os.path.expanduser('~/.poultry.cfg')
+    default_config_file = os.path.join(os.path.expanduser('~'), '.poultry.cfg')
 
     def __init__(self, config_file):
         config = SafeConfigParser()
@@ -140,4 +140,3 @@ class Merge(object):
     def __init__(self, name, inputs):
         self.name = name
         self.inputs = inputs
-
